# File generated from our OpenAPI spec by Stainless.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["InvoiceFetchUpcomingParams"]


class InvoiceFetchUpcomingParams(TypedDict, total=False):
    subscription_id: str
